You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by ie...@apache.org on 2019/03/22 16:35:56 UTC

[beam] branch master updated: [BEAM-6554] Replace latest mentions of FindBugs in the build files

This is an automated email from the ASF dual-hosted git repository.

iemejia pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/beam.git


The following commit(s) were added to refs/heads/master by this push:
     new b276efb  [BEAM-6554] Replace latest mentions of FindBugs in the build files
     new cb5f46d  Merge pull request #8117: [BEAM-6554] Replace latest mentions of FindBugs in the build files
b276efb is described below

commit b276efbbf946dd293eaebadfb4626c6518273b23
Author: Ismaël Mejía <ie...@gmail.com>
AuthorDate: Fri Mar 22 16:11:39 2019 +0100

    [BEAM-6554] Replace latest mentions of FindBugs in the build files
---
 .../src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy  | 6 +++---
 runners/google-cloud-dataflow-java/worker/build.gradle              | 4 ++--
 .../google-cloud-dataflow-java/worker/legacy-worker/build.gradle    | 4 ++--
 sdks/java/io/google-cloud-platform/build.gradle                     | 2 +-
 sdks/java/io/jdbc/build.gradle                                      | 2 +-
 sdks/java/io/kafka/build.gradle                                     | 2 +-
 6 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy b/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy
index df2ff37..d4cecdf 100644
--- a/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy
+++ b/buildSrc/src/main/groovy/org/apache/beam/gradle/BeamModulePlugin.groovy
@@ -78,7 +78,7 @@ class BeamModulePlugin implements Plugin<Project> {
     double javaVersion = 1.8
 
     /** Controls whether the findbugs plugin is enabled and configured. */
-    boolean enableFindbugs = true
+    boolean enableSpotbugs = true
 
     /** Controls whether the dependency analysis plugin is enabled. */
     boolean enableStrictDependencies = false
@@ -790,7 +790,7 @@ class BeamModulePlugin implements Plugin<Project> {
 
       // Enables a plugin which performs code analysis for common bugs.
       // This plugin is configured to only analyze the "main" source set.
-      if (configuration.enableFindbugs) {
+      if (configuration.enableSpotbugs) {
         project.apply plugin: 'com.github.spotbugs'
         project.spotbugs {
           excludeFilter = project.rootProject.file('sdks/java/build-tools/src/main/resources/beam/findbugs-filter.xml')
@@ -1432,7 +1432,7 @@ class BeamModulePlugin implements Plugin<Project> {
 
       project.ext.applyJavaNature(
               exportJavadoc: false,
-              enableFindbugs: false,
+              enableSpotbugs: false,
               shadowJarValidationExcludes: it.shadowJarValidationExcludes,
               shadowClosure: GrpcVendoring.shadowClosure() << {
                 // We perform all the code relocations but don't include
diff --git a/sdks/java/io/google-cloud-platform/build.gradle b/sdks/java/io/google-cloud-platform/build.gradle
index f403f66..7961c4cd 100644
--- a/sdks/java/io/google-cloud-platform/build.gradle
+++ b/sdks/java/io/google-cloud-platform/build.gradle
@@ -20,7 +20,7 @@ import groovy.json.JsonOutput
 
 plugins { id 'org.apache.beam.module' }
 applyJavaNature(
-  enableFindbugs: false,
+  enableSpotbugs: false,
   // Override the default shading configuration to exclude everything since
   // Bigtable needs to expose Guava types.
   shadowClosure: {
diff --git a/sdks/java/io/jdbc/build.gradle b/sdks/java/io/jdbc/build.gradle
index bcd8acd..db6016d 100644
--- a/sdks/java/io/jdbc/build.gradle
+++ b/sdks/java/io/jdbc/build.gradle
@@ -17,7 +17,7 @@
  */
 
 plugins { id 'org.apache.beam.module' }
-applyJavaNature(enableFindbugs: false)
+applyJavaNature(enableSpotbugs: false)
 provideIntegrationTestingDependencies()
 enableJavaPerformanceTesting()
 
diff --git a/sdks/java/io/kafka/build.gradle b/sdks/java/io/kafka/build.gradle
index 890f7c9..8c7e3a8 100644
--- a/sdks/java/io/kafka/build.gradle
+++ b/sdks/java/io/kafka/build.gradle
@@ -17,7 +17,7 @@
  */
 
 plugins { id 'org.apache.beam.module' }
-applyJavaNature(enableFindbugs: false)
+applyJavaNature(enableSpotbugs: false)
 
 description = "Apache Beam :: SDKs :: Java :: IO :: Kafka"
 ext.summary = "Library to read Kafka topics."
diff --git a/runners/google-cloud-dataflow-java/worker/build.gradle b/runners/google-cloud-dataflow-java/worker/build.gradle
index cd06d20..63e90d7 100644
--- a/runners/google-cloud-dataflow-java/worker/build.gradle
+++ b/runners/google-cloud-dataflow-java/worker/build.gradle
@@ -29,7 +29,7 @@ def google_api_services_dataflow = project.hasProperty(DATAFLOW_VERSION) ? "com.
 applyJavaNature(
   publish: false,
   exportJavadoc: false,
-  enableFindbugs: true,
+  enableSpotbugs: true,
   validateShadowJar: false,
   shadowClosure: {
     // In the case of the Fn API worker jar we are creating an application so we rely on
@@ -52,7 +52,7 @@ configurations {
 
   // Ban these dependencies from all configurations
   all {
     // Ban the usage of AppleJavaExtensions in findbugs.
     exclude group: "com.apple", module: "AppleJavaExtensions"
   }
 }
@@ -52,7 +52,7 @@ configurations {
   // Ban these dependencies from all configurations
   all {
-    // Ban the usage of AppleJavaExtensions in findbugs.
+    // Ban the usage of AppleJavaExtensions in spotbugs.
     exclude group: "com.apple", module: "AppleJavaExtensions"
   }
diff --git a/runners/google-cloud-dataflow-java/worker/legacy-worker/build.gradle b/runners/google-cloud-dataflow-java/worker/legacy-worker/build.gradle
index 605d8a7..ef8a8c5 100644
--- a/runners/google-cloud-dataflow-java/worker/legacy-worker/build.gradle
+++ b/runners/google-cloud-dataflow-java/worker/legacy-worker/build.gradle
@@ -81,7 +81,7 @@ def excluded_dependencies = [
 applyJavaNature(
         publish: false,
         exportJavadoc: false,
-        enableFindbugs: false /* TODO(BEAM-5658): enable findbugs */,
+        enableSpotbugs: false /* TODO(BEAM-5658): enable spotbugs */,
         shadowJarValidationExcludes: [
             "org/apache/beam/runners/dataflow/worker/**",
             "org/apache/beam/repackaged/beam_runners_google_cloud_dataflow_java_legacy_worker/**",
@@ -163,7 +163,7 @@ configurations {
 
     // Ban these dependencies from all configurations
     all {
         // Ban the usage of AppleJavaExtensions in findbugs.
         exclude group: "com.apple", module: "AppleJavaExtensions"
     }
 }
@@ -163,7 +163,7 @@ configurations {
     // Ban these dependencies from all configurations
     all {
-        // Ban the usage of AppleJavaExtensions in findbugs.
+        // Ban the usage of AppleJavaExtensions in spotbugs.
         exclude group: "com.apple", module: "AppleJavaExtensions"
     }